import { CSElement } from '../core/CSElement';
import { ElementOptions } from '../types/interfaces';
/**
 * Builder для удобного создания элементов с цепочкой вызовов
 */
export declare class ElementBuilder {
    private _name;
    private _data;
    private _index?;
    private _children;
    /**
     * Установить имя элемента
     */
    name(name: string): this;
    /**
     * Установить индекс элемента
     */
    index(index: number): this;
    /**
     * Добавить данные
     */
    data(key: string, value: any): this;
    /**
     * Добавить несколько данных сразу
     */
    dataObject(data: Record<string, any>): this;
    /**
     * Добавить дочерний элемент
     */
    child(name: string, options?: ElementOptions): this;
    /**
     * Добавить несколько дочерних элементов
     */
    children(...names: string[]): this;
    /**
     * Построить элемент
     */
    build(): Promise<CSElement>;
    /**
     * Построить и добавить к родителю
     */
    buildAndAddTo(parent: CSElement): Promise<CSElement>;
    /**
     * Статический метод для создания builder
     */
    static create(name?: string): ElementBuilder;
}
//# sourceMappingURL=ElementBuilder.d.ts.map