import { EventEmitter } from 'eventemitter3';
import { CSElement } from './CSElement';
/**
 * Пространство элементов - единое место для управления всеми элементами
 */
export declare class ElementSpace extends EventEmitter {
    private _elements;
    private _rootElements;
    private _lock;
    private _name;
    constructor(name?: string);
    /**
     * Получить имя пространства
     */
    get name(): string;
    /**
     * Создать новый элемент в пространстве
     */
    createElement(name: string, options?: any): Promise<CSElement>;
    /**
     * Получить элемент по ID
     */
    getElementById(id: string): CSElement | null;
    /**
     * Найти элементы по имени
     */
    getElementsByName(name: string): CSElement[];
    /**
     * Получить все корневые элементы (без владельцев)
     */
    getRootElements(): CSElement[];
    /**
     * Получить все элементы
     */
    getAllElements(): CSElement[];
    /**
     * Удалить элемент из пространства
     */
    removeElement(element: CSElement): Promise<boolean>;
    /**
     * Найти элементы по условию
     */
    findElements(predicate: (element: CSElement) => boolean): CSElement[];
    /**
     * Найти первый элемент по условию
     */
    findElement(predicate: (element: CSElement) => boolean): CSElement | null;
    /**
     * Обход всех элементов в глубину
     */
    traverseDepthFirst(callback: (element: CSElement) => void | Promise<void>, startFrom?: CSElement): Promise<void>;
    /**
     * Обход всех элементов в ширину
     */
    traverseBreadthFirst(callback: (element: CSElement) => void | Promise<void>, startFrom?: CSElement): Promise<void>;
    /**
     * Очистить пространство
     */
    clear(): Promise<void>;
    /**
     * Подписаться на события элемента
     */
    private _subscribeToElement;
    /**
     * Отписаться от событий элемента
     */
    private _unsubscribeFromElement;
    /**
     * Экспорт структуры в JSON
     */
    toJSON(): any;
}
//# sourceMappingURL=ElementSpace.d.ts.map