import { ICSElement } from '../types/interfaces';
import { IElementInspector, ElementInspectionInfo, StructureSnapshot, SerializationOptions, SerializationResult } from '../types/devtools-interfaces';
/**
 * Инспектор элементов CSElement
 * Предоставляет инструменты для анализа структуры и сериализации
 */
export declare class ElementInspector implements IElementInspector {
    private static readonly VERSION;
    /**
     * Получить детальную информацию об элементе
     */
    inspect(element: ICSElement): ElementInspectionInfo;
    /**
     * Создать снимок всей структуры начиная с корневого элемента
     */
    createSnapshot(rootElement: ICSElement): StructureSnapshot;
    /**
     * Сериализовать элемент в JSON-совместимый формат
     */
    serialize(element: ICSElement, options?: SerializationOptions): SerializationResult;
    /**
     * Десериализовать элемент из данных
     */
    deserialize(data: any): ICSElement;
    /**
     * Найти элемент по пути от корневого элемента
     */
    findByPath(rootElement: ICSElement, path: string[]): ICSElement | null;
    /**
     * Получить путь от корня до элемента
     */
    getElementPath(element: ICSElement): string[];
    /**
     * Найти родительский элемент
     */
    private findParent;
    /**
     * Вычислить глубину элемента в структуре
     */
    private calculateDepth;
    /**
     * Извлечь данные элемента
     */
    private extractData;
    /**
     * Получить время создания элемента
     */
    private getCreationTime;
    /**
     * Получить время последней модификации
     */
    private getModificationTime;
    /**
     * Вычислить размер элемента в байтах (приблизительно)
     */
    private calculateSize;
    /**
     * Рекурсивно обойти всю структуру
     */
    private traverseStructure;
    /**
     * Оценить использование памяти
     */
    private estimateMemoryUsage;
    /**
     * Компактный формат сериализации
     */
    private compactFormat;
    /**
     * Отладочный формат сериализации
     */
    private debugFormat;
}
//# sourceMappingURL=ElementInspector.d.ts.map