"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ElementBuilder = void 0;
const CSElement_1 = require("../core/CSElement");
/**
 * Builder для удобного создания элементов с цепочкой вызовов
 */
class ElementBuilder {
    constructor() {
        this._name = '';
        this._data = new Map();
        this._children = [];
    }
    /**
     * Установить имя элемента
     */
    name(name) {
        this._name = name;
        return this;
    }
    /**
     * Установить индекс элемента
     */
    index(index) {
        this._index = index;
        return this;
    }
    /**
     * Добавить данные
     */
    data(key, value) {
        this._data.set(key, value);
        return this;
    }
    /**
     * Добавить несколько данных сразу
     */
    dataObject(data) {
        Object.entries(data).forEach(([key, value]) => {
            this._data.set(key, value);
        });
        return this;
    }
    /**
     * Добавить дочерний элемент
     */
    child(name, options) {
        this._children.push({ name, options });
        return this;
    }
    /**
     * Добавить несколько дочерних элементов
     */
    children(...names) {
        names.forEach(name => {
            this._children.push({ name });
        });
        return this;
    }
    /**
     * Построить элемент
     */
    async build() {
        const element = new CSElement_1.CSElement(this._name, {
            data: this._data,
            index: this._index
        });
        // Добавляем дочерние элементы
        for (const child of this._children) {
            await element.addElement(child.name, child.options);
        }
        return element;
    }
    /**
     * Построить и добавить к родителю
     */
    async buildAndAddTo(parent) {
        const element = await this.build();
        await parent.addElement(element);
        return element;
    }
    /**
     * Статический метод для создания builder
     */
    static create(name) {
        const builder = new ElementBuilder();
        if (name) {
            builder.name(name);
        }
        return builder;
    }
}
exports.ElementBuilder = ElementBuilder;
