"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AsyncLock = void 0;
/**
 * Асинхронная блокировка для обеспечения потокобезопасности
 */
class AsyncLock {
    constructor() {
        this._queue = [];
        this._locked = false;
    }
    /**
     * Получить блокировку
     */
    async acquire() {
        return new Promise((resolve) => {
            if (!this._locked) {
                this._locked = true;
                resolve();
            }
            else {
                this._queue.push(resolve);
            }
        });
    }
    /**
     * Освободить блокировку
     */
    release() {
        if (!this._locked) {
            throw new Error('Cannot release an unlocked lock');
        }
        const next = this._queue.shift();
        if (next) {
            next();
        }
        else {
            this._locked = false;
        }
    }
    /**
     * Проверить заблокирована ли блокировка
     */
    isLocked() {
        return this._locked;
    }
    /**
     * Выполнить функцию с блокировкой
     */
    async withLock(fn) {
        await this.acquire();
        try {
            return await fn();
        }
        finally {
            this.release();
        }
    }
}
exports.AsyncLock = AsyncLock;
