import { CSElement } from './core/CSElement';
/**
 * CSElement - Потокобезопасная библиотека для работы с графовыми структурами
 */
export { CSElement };
export { ICSElement, ICSElementPattern, ElementOptions, ElementValue, ElementEvent, ElementEventType, SerializationOptions, SerializedElement, ValidationRule, ValidationResult, ValidationError, QuerySelector, PersistenceAdapter, PerformanceMetrics } from './types/interfaces';
export { CSElementPlugin, LifecycleHooks, MiddlewareFunction, MiddlewareContext, MiddlewareConfig, MiddlewareResult, MiddlewareStats, MiddlewarePriority, AdvancedMiddlewareManager, PluginManager as IPluginManager, PluginOptions, PluginInfo, PluginEvent } from './types/plugin-interfaces';
export { VisualizationFormat, LayoutType, TreeDirection, NodeStyle, EdgeStyle, VisualizationOptions, VisualizationResult, VisualizationNode, VisualizationEdge, VisualizationGraph, VisualizationEngine, VisualizationManager as IVisualizationManager, VisualizationEvent, VisualizationTheme, FileExporter } from './types/visualization-interfaces';
export { AsyncLock } from './utils/AsyncLock';
export { generateId, deepClone, delay } from './utils/helpers';
export { ElementValidator, defaultValidator, ValidationType } from './utils/Validator';
export { QueryEngine, SelectorBuilder, CommonSelectors } from './utils/QueryEngine';
export { TypeScriptGenerator, generateTypesFromSchemas, generateTypesToFile } from './utils/TypeScriptGenerator';
export { BatchManager } from './batch/BatchManager';
export { DefaultBatchOperationFactory, DefaultBatchBuilder, BatchOperations } from './batch/BatchOperationFactory';
export { BatchOperationType, BatchPriority, BatchExecutionStrategy, BatchErrorMode, IBatchManager, BatchConfig, BatchResult, BatchProgress, BatchEventListener, BatchManagerStatistics, BatchOperationFactory, BatchBuilder } from './types/batch-interfaces';
export type { BatchOperation, BatchExecutionContext, BatchOperationResult, BatchValidationResult, BatchStatistics } from './types/batch-interfaces';
export { Blueprint } from './blueprint/Blueprint';
export { BlueprintBuilder } from './blueprint/BlueprintBuilder';
export { BlueprintManager } from './blueprint/BlueprintManager';
export * from './types/blueprint-interfaces';
export { PluginManager } from './core/PluginManager';
export { AdvancedMiddlewareManagerImpl } from './core/AdvancedMiddlewareManager';
export * from './types/persistence-interfaces';
export { MemoryStorageAdapter } from './persistence/MemoryStorageAdapter';
export { PersistenceManagerImpl } from './persistence/PersistenceManagerImpl';
export * from './types/transaction-interfaces';
export { LockManagerImpl } from './transactions/LockManagerImpl';
export { TransactionManagerImpl } from './transactions/TransactionManagerImpl';
export { VisualizationPlugin, visualizationPlugin } from './plugins/VisualizationPlugin';
export { ValidationPlugin, validationPlugin } from './plugins/ValidationPlugin';
export { CachePlugin, cachePlugin } from './plugins/CachePlugin';
export { MetricsPlugin, metricsPlugin } from './plugins/MetricsPlugin';
export { TransformPlugin, transformPlugin } from './plugins/TransformPlugin';
export { SerializationPlugin, serializationPlugin } from './plugins/SerializationPlugin';
export { SecurityPlugin } from './plugins/SecurityPlugin';
export { AnalyticsPlugin } from './plugins/AnalyticsPlugin';
export { BackupPlugin } from './plugins/BackupPlugin';
export { CompressionPlugin } from './plugins/CompressionPlugin';
export { NetworkPlugin } from './plugins/NetworkPlugin';
export { DevToolsPlugin, devToolsPlugin } from './plugins/DevToolsPlugin';
export { VisualizationManager } from './visualization/VisualizationManager';
export { AsciiEngine } from './visualization/engines/AsciiEngine';
export { SvgEngine } from './visualization/engines/SvgEngine';
export { HtmlEngine } from './visualization/engines/HtmlEngine';
export { DevToolsManager } from './devtools/DevToolsManager';
export { ElementInspector } from './devtools/ElementInspector';
export { PerformanceProfiler } from './devtools/PerformanceProfiler';
export * from './types/devtools-interfaces';
export { HistoryManagerImpl } from './history/HistoryManagerImpl';
export * from './types/history-interfaces';
export { ReactivityManagerImpl } from './reactivity/ReactivityManagerImpl';
export * from './types/reactivity-interfaces';
export { LiveQueryManagerImpl, LiveQueryBuilderImpl } from './live-queries/LiveQueryManagerImpl';
export * from './types/live-query-interfaces';
export { GraphAlgorithmsManagerImpl } from './graph/GraphAlgorithmsManagerImpl';
export * from './types/graph-interfaces';
export { StateMachine } from './state-machine/StateMachine';
export { StateMachineManagerImpl } from './state-machine/StateMachineManager';
export { StateMachineIntegration } from './core/StateMachineIntegration';
export * from './types/state-machine-interfaces';
export { TypedElement } from './typed-elements/TypedElement';
export { TypedElementManager, defaultTypedElementManager } from './typed-elements/TypedElementManager';
export * from './types/typed-elements-interfaces';
export { MigrationManager } from './migration/MigrationManager';
export { MemoryMigrationStorage } from './migration/MemoryMigrationStorage';
export { VersionUtils } from './migration/VersionUtils';
export { MigrationBuilder, createMigration } from './migration/MigrationBuilder';
export { MigrationRegistry, Migration, Up, Down, CanApply, CanRollback, Validate, DependsOn, Type, BaseMigration, SchemaMigration, DataMigration, MigrationUtils } from './migration/MigrationDecorators';
export { MigrationFactory, migrationFactory } from './migration/MigrationFactory';
export { MigrationRunner } from './migration/MigrationRunner';
export { MigrationScheduler } from './migration/MigrationScheduler';
export { MigrationLogger } from './migration/MigrationLogger';
export { MigrationSystem } from './migration/MigrationSystem';
export * from './types/migration-interfaces';
export { EventEmitter } from 'eventemitter3';
export declare const ElementBuilder: typeof CSElement;
export declare const ElementSpace: typeof CSElement;
export { useElement, useQuery, useCSElementById, useQueryOne, useCSElementSystem } from './react/hooks';
export { WorkerManager } from './workers/WorkerManager';
export { WorkerOperationType, WorkerMessage, WorkerResponse, WorkerError, WorkerConfig, WorkerPool, IWorkerManager, WorkerInstance, WorkerStatus, PoolStatus, DiffChange, MergeConflict, ThreeWayMergeResult, ChangeVisualization, DiffVisualizationOptions } from './types/worker-interfaces';
export { DiffEngine, DiffAlgorithm, MergeStrategy } from './diff/DiffEngine';
export declare const VERSION = "2.0.0";
//# sourceMappingURL=index.d.ts.map