/**
 * Хранилище миграций в памяти для CSElement
 */
/**
 * Реализация хранилища миграций в памяти
 */
export class MemoryMigrationStorage {
    constructor() {
        this.records = new Map();
    }
    /**
     * Сохранение записи о миграции
     */
    async saveRecord(record) {
        this.records.set(record.migrationId, { ...record });
    }
    /**
     * Получение записи о миграции
     */
    async getRecord(migrationId) {
        const record = this.records.get(migrationId);
        return record ? { ...record } : undefined;
    }
    /**
     * Получение всех записей
     */
    async getAllRecords() {
        return Array.from(this.records.values()).map(record => ({ ...record }));
    }
    /**
     * Получение записей по статусу
     */
    async getRecordsByStatus(status) {
        return Array.from(this.records.values())
            .filter(record => record.status === status)
            .map(record => ({ ...record }));
    }
    /**
     * Обновление статуса миграции
     */
    async updateStatus(migrationId, status) {
        const record = this.records.get(migrationId);
        if (record) {
            record.status = status;
            this.records.set(migrationId, record);
        }
    }
    /**
     * Удаление записи
     */
    async deleteRecord(migrationId) {
        this.records.delete(migrationId);
    }
    /**
     * Очистка всех записей
     */
    async clear() {
        this.records.clear();
    }
}
//# sourceMappingURL=MemoryMigrationStorage.js.map