/**
 * Менеджер визуализации CSElement
 */
import { EventEmitter } from 'eventemitter3';
import { ICSElement } from '../types/interfaces';
import { VisualizationManager as IVisualizationManager, VisualizationEngine, VisualizationGraph, VisualizationOptions, VisualizationResult, VisualizationFormat, VisualizationTheme } from '../types/visualization-interfaces';
export declare class VisualizationManager extends EventEmitter implements IVisualizationManager {
    private engines;
    private themes;
    constructor();
    /**
     * Инициализация стандартных тем
     */
    private initializeDefaultThemes;
    /**
     * Зарегистрировать движок визуализации
     */
    registerEngine(engine: VisualizationEngine): void;
    /**
     * Получить движок для формата
     */
    getEngine(format: VisualizationFormat): VisualizationEngine | null;
    /**
     * Получить все движки
     */
    getEngines(): VisualizationEngine[];
    /**
     * Получить тему по имени
     */
    getTheme(name: string): VisualizationTheme | null;
    /**
     * Добавить пользовательскую тему
     */
    addTheme(theme: VisualizationTheme): void;
    /**
     * Получить все темы
     */
    getThemes(): VisualizationTheme[];
    /**
     * Создать граф из элемента
     */
    createGraph(element: ICSElement, options?: VisualizationOptions): VisualizationGraph;
    /**
     * Создать метку для узла
     */
    private createNodeLabel;
    /**
     * Форматировать значение для отображения
     */
    private formatValue;
    /**
     * Применить тему к опциям
     */
    applyTheme(options: VisualizationOptions, themeName: string): VisualizationOptions;
    /**
     * Визуализировать элемент
     */
    visualize(element: ICSElement, options?: VisualizationOptions): Promise<VisualizationResult>;
    /**
     * Получить статистику менеджера
     */
    getStats(): {
        enginesCount: number;
        themesCount: number;
        supportedFormats: VisualizationFormat[];
    };
    /**
     * Очистить все движки (для тестирования)
     */
    clear(): void;
}
//# sourceMappingURL=VisualizationManager.d.ts.map